#!/usr/bin/env python
#
# SPDX-FileCopyrightText: 2018-2023 Espressif Systems (Shanghai) CO LTD
# SPDX-License-Identifier: Apache-2.0

from __future__ import print_function

import sys
from typing import Dict

try:
    import idf_size.core
except ImportError:
    sys.path.append('..')
    import idf_size.core


if __name__ == '__main__':
    # Should deliver a RuntimeError as the 'test' header doesn't exist
    try:
        idf_size.core.scan_to_header([], 'test')
    except RuntimeError as e:
        assert "Didn't find line" in str(e)

    # Should deliver a RuntimeError as there's no content under the heading
    try:
        idf_size.core.load_segments(['Memory Configuration'])
        pass
    except RuntimeError as e:
        assert 'End of file' in str(e)

    segments = {'iram0_0_seg': {'origin': 0, 'length': 0},
                'dram0_0_seg': {'origin': 0, 'length': 0}}
    sections = {}  # type: Dict

    print(idf_size.core.get_summary('a.map', segments, sections, 'esp32'), end='')



import os.path

from setuptools import find_packages, setup


def read(rel_path):
    here = os.path.abspath(os.path.dirname(__file__))
    with open(os.path.join(here, rel_path), "r") as fp:
        return fp.read()


def get_version(rel_path):
    for line in read(rel_path).splitlines():
        if line.startswith("__version__"):
            delim = '"' if '"' in line else "'"
            return line.split(delim)[1]
    else:
        raise RuntimeError("Unable to find version string.")


def get_long_description():
    with open("README.md", "r") as f:
        text = f.read()
    return text


setup(
    name="esp-idf-size",
    version=get_version("esp_idf_size/__init__.py"),
    author="Espressif Systems",
    author_email="",
    description="Firmware size analysis for ESP-IDF",
    long_description_content_type="text/markdown",
    long_description=get_long_description(),
    url="https://github.com/espressif/esp-idf-size",
    packages=find_packages(),
    python_requires=">=3.7",
    install_requires=["pyyaml"],
    extras_require={
        "dev": [
            "pre-commit",
            "coverage",
            "jsonschema",
        ],
    },
    keywords=["espressif", "embedded", "project", "size"],
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "Natural Language :: English",
        "Environment :: Console",
        "Topic :: Software Development :: Embedded Systems",
        "License :: OSI Approved :: Apache Software License",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Operating System :: POSIX",
        "Operating System :: Microsoft :: Windows",
        "Operating System :: MacOS :: MacOS X",
    ],
    include_package_data=True,
)
